@@ -707,6 +707,14 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                     put_on_same_scale=False,
                     title= title)
                 fig.show()
+                dollar_df = daily_df[[me_strat]].copy()
+                new_names = {me_strat: 'Performance Strategy'}
+                dollar_df = dollar_df.rename(columns=new_names)
+                fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=dollar_df,
+                                                                                 logy=True, split=False,
+                                                                                 put_on_same_scale=False,
+                                                                                 title=f'Strategy {title})')
+                fig.show()
 
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'advance_kpis_details_{title}.xlsx',
